function [D] = DHellinger_kNN_k_estimation(X,Y,co)
%Estimates the Hellinger distance of X and Y (X(:,t), Y(:,t) is the t^th sample)
%using the kNN method (S={k}). The number of samples in X [=size(X,2)] and Y [=size(Y,2)] can be different. Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'D<name>_estimation', to ease embedding new divergence estimation methods.
%
%REFERENCE: 
%	Barnabas Poczos and Liang Xiong and Dougal Sutherland and Jeff Schneider. Support Distribution Machines. Technical Report, 2012. "http://arxiv.org/abs/1202.0302"
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%co.mult:OK.

if size(X,1)~=size(Y,1)
    disp('Error: the dimension of X and Y must be equal.');
end

%D_ab (Bhattacharyya coefficient):
	if co.p %[p(x)dx]
		D_ab = estimate_Dab(X,Y,co);
	else %[q(x)dx]
		D_ab = estimate_Dab(Y,X,co);
	end

%D = sqrt(1-D_ab);%theoretically
D = sqrt(abs(1-D_ab));%abs() to avoid possible 'sqrt(negative)' values due to the finite number of samples
