function [co] = IRenyi_HRenyi_initialization(mult)
%Initialization of the "meta" Renyi mutual information estimator. The estimator uses the identity: 
%I_{alpha}(X) = -H_{alpha}(Z), where Z =[F_1(X_1);...;F_d(X_d)] is the copula transformation of X; F_i is the cdf of X_i.
%
%Note:
%   1)The estimator is treated as a cost object (co). 
%   2)We make use of the naming convention 'I<name>_estimation', to ease embedding new mutual information estimation methods.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'Renyi_HRenyi';
    co.mul = mult;
    co.alpha = 0.99;
    
%other fields:    
    co.member_name = 'Renyi_kNN_k'; %you can change it to any Renyi entropy estimator 
    co.member_co = H_initialization(co.member_name,mult);
    co.member_co.alpha = co.alpha;
